/*******************************************************************************
* Freescale Semiconductor Inc.
* (c) Copyright 2015 Freescale Semiconductor, Inc.
* ALL RIGHTS RESERVED.
********************************************************************************
Services performed by FREESCALE in this matter are performed AS IS and without
any warranty. CUSTOMER retains the final decision relative to the total design
and functionality of the end product. FREESCALE neither guarantees nor will be
held liable by CUSTOMER for the success of this project.
FREESCALE DISCLAIMS ALL WARRANTIES, EXPRESSED, IMPLIED OR STATUTORY INCLUDING,
BUT NOT LIMITED TO, IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
A PARTICULAR PURPOSE ON ANY HARDWARE, SOFTWARE ORE ADVISE SUPPLIED 
TO THE PROJECT BY FREESCALE, AND OR NAY PRODUCT RESULTING FROM FREESCALE 
SERVICES. IN NO EVENT SHALL FREESCALE BE LIABLE FOR INCIDENTAL OR CONSEQUENTIAL 
DAMAGES ARISING OUT OF THIS AGREEMENT.
CUSTOMER agrees to hold FREESCALE harmless against any and all claims demands 
or actions by anyone on account of any damage, or injury, whether commercial,
contractual, or tortuous, rising directly or indirectly as a result 
of the advise or assistance supplied CUSTOMER in connection with product, 
services or goods supplied under this Agreement.
********************************************************************************
* File:             Interrupts.c
* Owner             David Tosenovjan
* Version           0.1
* Date              Dec-15-2015
* Classification:   General Business Information
* Brief:            Interrupts initialization code
********************************************************************************
********************************************************************************
* Detailed Description:
*
********************************************************************************
Revision History:
Ver  Date         Author            Description of Changes
0.1  Dec-15-2015  David Tosenovjan  Initial version
*******************************************************************************/

/*******************************************************************************
* Includes                                                                     
*******************************************************************************/
#include "MPC577xC.h"
#include "Interrupts.h"

/*******************************************************************************
* External objects
*******************************************************************************/
extern const uint32_t IntcIsrVectorTable[];
extern void e200zX_Interrupt_Setup(void);

/*******************************************************************************
* Global variables
*******************************************************************************/

/*******************************************************************************
* Constants and macros
*******************************************************************************/

/*******************************************************************************
* Local types
*******************************************************************************/

/*******************************************************************************
* Local function prototypes
*******************************************************************************/

/*******************************************************************************
* Local variables
*******************************************************************************/

/*******************************************************************************
* Local functions
*******************************************************************************/

/*******************************************************************************
* Global functions
*******************************************************************************/

/*******************************************************************************
Function Name : Interrupts_init
Engineer      : David Tosenovjan
Date          : Dec-15-2015
Parameters    : 
Modifies      : 
Returns       : 
Notes         : this function must be called by both cores
Issues        : int. vector table is expected to be the same for both cores
*******************************************************************************/
void Interrupts_init(void)
{ 
    /* Initialize INTC for software vector mode */
    INTC.MCR.R = 0x00000000;       
  
    /* configure IVPR and IVORx offsets, also includes a trap for all core 
       exceptions, excluding IVOR4 exceptions which have seperate handler */
    e200zX_Interrupt_Setup();
  
    /* Set INTC ISR vector table base address */
    INTC.IACKR.R = (uint32_t) &IntcIsrVectorTable[0];
    INTC.IACKR_PRC1.R = (uint32_t) &IntcIsrVectorTable[0];

    /* assing required peripheral priorities */
    //INTC.PSR[301].R = PRC_SEL_CPU0 | PRC_PRI(1);    // PIT0
    INTC.PSR[303].R = PRC_SEL_CPU1 | PRC_PRI(2);    // PIT2
    INTC.PSR[348].R = PRC_SEL_CPU0 | PRC_PRI(1);    // M_CAN0_0, M_CAN0_1, M_CAN1_0,
                                                    // M_CAN1_1 Combined Interrupts
}


/*******************************************************************************
Function Name : Interrupts_enable_Core0
Engineer      : David Tosenovjan
Date          : Dec-15-2015
Parameters    : 
Modifies      : 
Returns       : 
Notes         : 
Issues        : 
*******************************************************************************/
void Interrupts_enable_Core0(void)
{ 
    /* lower current INTC priority to start INTC interrupts */
    INTC.CPR.B.PRI = 0;

    /* enable interrupts */
    asm(" wrteei 1");
}


/*******************************************************************************
Function Name : Interrupts_enable_Core1
Engineer      : David Tosenovjan
Date          : Dec-15-2015
Parameters    : 
Modifies      : 
Returns       : 
Notes         : 
Issues        : 
*******************************************************************************/
void Interrupts_enable_Core1(void)
{ 
    /* lower current INTC priority to start INTC interrupts */
    INTC.CPR_PRC1.B.PRI = 0;

    /* enable interrupts */
    asm(" wrteei 1");
}

