/*******************************************************************************
* Freescale Semiconductor Inc.
* (c) Copyright 2015 Freescale Semiconductor, Inc.
* ALL RIGHTS RESERVED.
********************************************************************************
Services performed by FREESCALE in this matter are performed AS IS and without
any warranty. CUSTOMER retains the final decision relative to the total design
and functionality of the end product. FREESCALE neither guarantees nor will be
held liable by CUSTOMER for the success of this project.
FREESCALE DISCLAIMS ALL WARRANTIES, EXPRESSED, IMPLIED OR STATUTORY INCLUDING,
BUT NOT LIMITED TO, IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
A PARTICULAR PURPOSE ON ANY HARDWARE, SOFTWARE ORE ADVISE SUPPLIED 
TO THE PROJECT BY FREESCALE, AND OR NAY PRODUCT RESULTING FROM FREESCALE 
SERVICES. IN NO EVENT SHALL FREESCALE BE LIABLE FOR INCIDENTAL OR CONSEQUENTIAL 
DAMAGES ARISING OUT OF THIS AGREEMENT.
CUSTOMER agrees to hold FREESCALE harmless against any and all claims demands 
or actions by anyone on account of any damage, or injury, whether commercial,
contractual, or tortuous, rising directly or indirectly as a result 
of the advise or assistance supplied CUSTOMER in connection with product, 
services or goods supplied under this Agreement.
********************************************************************************
* File:             MPC5777C_IsrVecTab.c
* Owner:            David Tosenovjan
* Version:          0.1
* Date:             Aug-25-2015
* Classification:   General Business Information
* Brief:            ISR routines for INTC in HW or SW vector mode
********************************************************************************
********************************************************************************
* Detailed Description:
* ISR routines for MPC5777C
* 
********************************************************************************
Revision History:
Ver  Date         Author            Description of Changes
0.1  Aug-25-2015  David Tosenovjan  Initial Version for MPC5777C
*******************************************************************************/


/*******************************************************************************
* Includes                                                                     
*******************************************************************************/
#include "Interrupts.h"

/*******************************************************************************
* Local functions
*******************************************************************************/
void NonHandledINTCException();

/*******************************************************************************
* Global variables
*******************************************************************************/
//extern void PIT0_ISR(void);
extern void PIT3_ISR(void);
extern void MCAN_ISR(void);

// ****************************************************************************
//in case you are using SW interrupts and VLE is enabled use this
#pragma asm
  .macro ISRline value
  .long  value
  .endm    
#pragma endasm

//In case you are using HW use this 
//#pragma asm
//    .macro ISRline value
//    e_b  value
//	nop
//	nop
//	nop
//    .endm
//#pragma endasm

// ****************************************************************************
// ************************ Internal Constants and Variables ******************
// ****************************************************************************
/* Use next line with Green Hills compile */
#pragma ghs section rodata=".isrvectab"

// This table contains all ISR routines called when peripheral interrupt occurs.
// The table is used only when INTC is configured to work in "SW vector mode"

#pragma asm
   
  .section  ".isrvectab", "vax"
  .vle

    
  .global IntcIsrVectorTable
IntcIsrVectorTable:

  ; #IRQ 000                               ;*** Source of interrupt: SOFTWARE ***
  ISRline NonHandledINTCException          ;Vec 000,
  ISRline NonHandledINTCException          ;Vec 001,
  ISRline NonHandledINTCException          ;Vec 002,
  ISRline NonHandledINTCException          ;Vec 003,
  ISRline NonHandledINTCException          ;Vec 004,
  ISRline NonHandledINTCException          ;Vec 005,
  ISRline NonHandledINTCException          ;Vec 006,
  ISRline NonHandledINTCException          ;Vec 007,
  ISRline NonHandledINTCException          ;Vec 008,
  ISRline NonHandledINTCException          ;Vec 009,
  ISRline NonHandledINTCException          ;Vec 010,
  ISRline NonHandledINTCException          ;Vec 011,
  ISRline NonHandledINTCException          ;Vec 012,
  ISRline NonHandledINTCException          ;Vec 013,
  ISRline NonHandledINTCException          ;Vec 014,
  ISRline NonHandledINTCException          ;Vec 015,
  ISRline NonHandledINTCException          ;Vec 016,
  ISRline NonHandledINTCException          ;Vec 017,
  ISRline NonHandledINTCException          ;Vec 018,
  ISRline NonHandledINTCException          ;Vec 019,
  ISRline NonHandledINTCException          ;Vec 020,
  ISRline NonHandledINTCException          ;Vec 021,
  ISRline NonHandledINTCException          ;Vec 022,
  ISRline NonHandledINTCException          ;Vec 023,
  ISRline NonHandledINTCException          ;Vec 024,
  ISRline NonHandledINTCException          ;Vec 025,
  ISRline NonHandledINTCException          ;Vec 026,
  ISRline NonHandledINTCException          ;Vec 027,
  ISRline NonHandledINTCException          ;Vec 028,
  ISRline NonHandledINTCException          ;Vec 029,
  ISRline NonHandledINTCException          ;Vec 030,
  ISRline NonHandledINTCException          ;Vec 031,
  ISRline NonHandledINTCException          ;Vec 032,
  ISRline NonHandledINTCException          ;Vec 033,
  ISRline NonHandledINTCException          ;Vec 034,
  ISRline NonHandledINTCException          ;Vec 035,
  ISRline NonHandledINTCException          ;Vec 036,
  ISRline NonHandledINTCException          ;Vec 037,
  ISRline NonHandledINTCException          ;Vec 038,
  ISRline NonHandledINTCException          ;Vec 039,
  ISRline NonHandledINTCException          ;Vec 040,
  ISRline NonHandledINTCException          ;Vec 041,
  ISRline NonHandledINTCException          ;Vec 042,
  ISRline NonHandledINTCException          ;Vec 043,
  ISRline NonHandledINTCException          ;Vec 044,
  ISRline NonHandledINTCException          ;Vec 045,
  ISRline NonHandledINTCException          ;Vec 046,
  ISRline NonHandledINTCException          ;Vec 047,
  ISRline NonHandledINTCException          ;Vec 048,
  ISRline NonHandledINTCException          ;Vec 049,
  ISRline NonHandledINTCException          ;Vec 050,
  ISRline NonHandledINTCException          ;Vec 051,
  ISRline NonHandledINTCException          ;Vec 052,
  ISRline NonHandledINTCException          ;Vec 053,
  ISRline NonHandledINTCException          ;Vec 054,
  ISRline NonHandledINTCException          ;Vec 055,
  ISRline NonHandledINTCException          ;Vec 056,
  ISRline NonHandledINTCException          ;Vec 057,
  ISRline NonHandledINTCException          ;Vec 058,
  ISRline NonHandledINTCException          ;Vec 059,
  ISRline NonHandledINTCException          ;Vec 060,
  ISRline NonHandledINTCException          ;Vec 061,
  ISRline NonHandledINTCException          ;Vec 062,
  ISRline NonHandledINTCException          ;Vec 063,
  ISRline NonHandledINTCException          ;Vec 064,
  ISRline NonHandledINTCException          ;Vec 065,
  ISRline NonHandledINTCException          ;Vec 066,
  ISRline NonHandledINTCException          ;Vec 067,
  ISRline NonHandledINTCException          ;Vec 068,
  ISRline NonHandledINTCException          ;Vec 069,
  ISRline NonHandledINTCException          ;Vec 070,
  ISRline NonHandledINTCException          ;Vec 071,
  ISRline NonHandledINTCException          ;Vec 072,
  ISRline NonHandledINTCException          ;Vec 073,
  ISRline NonHandledINTCException          ;Vec 074,
  ISRline NonHandledINTCException          ;Vec 075,
  ISRline NonHandledINTCException          ;Vec 076,
  ISRline NonHandledINTCException          ;Vec 077,
  ISRline NonHandledINTCException          ;Vec 078,
  ISRline NonHandledINTCException          ;Vec 079,
  ISRline NonHandledINTCException          ;Vec 080,
  ISRline NonHandledINTCException          ;Vec 081,
  ISRline NonHandledINTCException          ;Vec 082,
  ISRline NonHandledINTCException          ;Vec 083,
  ISRline NonHandledINTCException          ;Vec 084,
  ISRline NonHandledINTCException          ;Vec 085,
  ISRline NonHandledINTCException          ;Vec 086,
  ISRline NonHandledINTCException          ;Vec 087,
  ISRline NonHandledINTCException          ;Vec 088,
  ISRline NonHandledINTCException          ;Vec 089,
  ISRline NonHandledINTCException          ;Vec 090,
  ISRline NonHandledINTCException          ;Vec 091,
  ISRline NonHandledINTCException          ;Vec 092,
  ISRline NonHandledINTCException          ;Vec 093,
  ISRline NonHandledINTCException          ;Vec 094,
  ISRline NonHandledINTCException          ;Vec 095,
  ISRline NonHandledINTCException          ;Vec 096,
  ISRline NonHandledINTCException          ;Vec 097,
  ISRline NonHandledINTCException          ;Vec 098,
  ISRline NonHandledINTCException          ;Vec 099,
  ISRline NonHandledINTCException          ;Vec 100,
  ISRline NonHandledINTCException          ;Vec 101,
  ISRline NonHandledINTCException          ;Vec 102,
  ISRline NonHandledINTCException          ;Vec 103,
  ISRline NonHandledINTCException          ;Vec 104,
  ISRline NonHandledINTCException          ;Vec 105,
  ISRline NonHandledINTCException          ;Vec 106,
  ISRline NonHandledINTCException          ;Vec 107,
  ISRline NonHandledINTCException          ;Vec 108,
  ISRline NonHandledINTCException          ;Vec 109,
  ISRline NonHandledINTCException          ;Vec 110,
  ISRline NonHandledINTCException          ;Vec 111,
  ISRline NonHandledINTCException          ;Vec 112,
  ISRline NonHandledINTCException          ;Vec 113,
  ISRline NonHandledINTCException          ;Vec 114,
  ISRline NonHandledINTCException          ;Vec 115,
  ISRline NonHandledINTCException          ;Vec 116,
  ISRline NonHandledINTCException          ;Vec 117,
  ISRline NonHandledINTCException          ;Vec 118,
  ISRline NonHandledINTCException          ;Vec 119,
  ISRline NonHandledINTCException          ;Vec 120,
  ISRline NonHandledINTCException          ;Vec 121,
  ISRline NonHandledINTCException          ;Vec 122,
  ISRline NonHandledINTCException          ;Vec 123,
  ISRline NonHandledINTCException          ;Vec 124,
  ISRline NonHandledINTCException          ;Vec 125,
  ISRline NonHandledINTCException          ;Vec 126,
  ISRline NonHandledINTCException          ;Vec 127,
  ISRline NonHandledINTCException          ;Vec 128,
  ISRline NonHandledINTCException          ;Vec 129,
  ISRline NonHandledINTCException          ;Vec 130,
  ISRline NonHandledINTCException          ;Vec 131,
  ISRline NonHandledINTCException          ;Vec 132,
  ISRline NonHandledINTCException          ;Vec 133,
  ISRline NonHandledINTCException          ;Vec 134,
  ISRline NonHandledINTCException          ;Vec 135,
  ISRline NonHandledINTCException          ;Vec 136,
  ISRline NonHandledINTCException          ;Vec 137,
  ISRline NonHandledINTCException          ;Vec 138,
  ISRline NonHandledINTCException          ;Vec 139,
  ISRline NonHandledINTCException          ;Vec 140,
  ISRline NonHandledINTCException          ;Vec 141,
  ISRline NonHandledINTCException          ;Vec 142,
  ISRline NonHandledINTCException          ;Vec 143,
  ISRline NonHandledINTCException          ;Vec 144,
  ISRline NonHandledINTCException          ;Vec 145,
  ISRline NonHandledINTCException          ;Vec 146,
  ISRline NonHandledINTCException          ;Vec 147,
  ISRline NonHandledINTCException          ;Vec 148,
  ISRline NonHandledINTCException          ;Vec 149,
  ISRline NonHandledINTCException          ;Vec 150,
  ISRline NonHandledINTCException          ;Vec 151,
  ISRline NonHandledINTCException          ;Vec 152,
  ISRline NonHandledINTCException          ;Vec 153,
  ISRline NonHandledINTCException          ;Vec 154,
  ISRline NonHandledINTCException          ;Vec 155,
  ISRline NonHandledINTCException          ;Vec 156,
  ISRline NonHandledINTCException          ;Vec 157,
  ISRline NonHandledINTCException          ;Vec 158,
  ISRline NonHandledINTCException          ;Vec 159,
  ISRline NonHandledINTCException          ;Vec 160,
  ISRline NonHandledINTCException          ;Vec 161,
  ISRline NonHandledINTCException          ;Vec 162,
  ISRline NonHandledINTCException          ;Vec 163,
  ISRline NonHandledINTCException          ;Vec 164,
  ISRline NonHandledINTCException          ;Vec 165,
  ISRline NonHandledINTCException          ;Vec 166,
  ISRline NonHandledINTCException          ;Vec 167,
  ISRline NonHandledINTCException          ;Vec 168,
  ISRline NonHandledINTCException          ;Vec 169,
  ISRline NonHandledINTCException          ;Vec 170,
  ISRline NonHandledINTCException          ;Vec 171,
  ISRline NonHandledINTCException          ;Vec 172,
  ISRline NonHandledINTCException          ;Vec 173,
  ISRline NonHandledINTCException          ;Vec 174,
  ISRline NonHandledINTCException          ;Vec 175,
  ISRline NonHandledINTCException          ;Vec 176,
  ISRline NonHandledINTCException          ;Vec 177,
  ISRline NonHandledINTCException          ;Vec 178,
  ISRline NonHandledINTCException          ;Vec 179,
  ISRline NonHandledINTCException          ;Vec 180,
  ISRline NonHandledINTCException          ;Vec 181,
  ISRline NonHandledINTCException          ;Vec 182,
  ISRline NonHandledINTCException          ;Vec 183,
  ISRline NonHandledINTCException          ;Vec 184,
  ISRline NonHandledINTCException          ;Vec 185,
  ISRline NonHandledINTCException          ;Vec 186,
  ISRline NonHandledINTCException          ;Vec 187,
  ISRline NonHandledINTCException          ;Vec 188,
  ISRline NonHandledINTCException          ;Vec 189,
  ISRline NonHandledINTCException          ;Vec 190,
  ISRline NonHandledINTCException          ;Vec 191,
  ISRline NonHandledINTCException          ;Vec 192,
  ISRline NonHandledINTCException          ;Vec 193,
  ISRline NonHandledINTCException          ;Vec 194,
  ISRline NonHandledINTCException          ;Vec 195,
  ISRline NonHandledINTCException          ;Vec 196,
  ISRline NonHandledINTCException          ;Vec 197,
  ISRline NonHandledINTCException          ;Vec 198,
  ISRline NonHandledINTCException          ;Vec 199,
  ISRline NonHandledINTCException          ;Vec 200,
  ISRline NonHandledINTCException          ;Vec 201,
  ISRline NonHandledINTCException          ;Vec 202,
  ISRline NonHandledINTCException          ;Vec 203,
  ISRline NonHandledINTCException          ;Vec 204,
  ISRline NonHandledINTCException          ;Vec 205,
  ISRline NonHandledINTCException          ;Vec 206,
  ISRline NonHandledINTCException          ;Vec 207,
  ISRline NonHandledINTCException          ;Vec 208,
  ISRline NonHandledINTCException          ;Vec 209,
  ISRline NonHandledINTCException          ;Vec 210,
  ISRline NonHandledINTCException          ;Vec 211,
  ISRline NonHandledINTCException          ;Vec 212,
  ISRline NonHandledINTCException          ;Vec 213,
  ISRline NonHandledINTCException          ;Vec 214,
  ISRline NonHandledINTCException          ;Vec 215,
  ISRline NonHandledINTCException          ;Vec 216,
  ISRline NonHandledINTCException          ;Vec 217,
  ISRline NonHandledINTCException          ;Vec 218,
  ISRline NonHandledINTCException          ;Vec 219,
  ISRline NonHandledINTCException          ;Vec 220,
  ISRline NonHandledINTCException          ;Vec 221,
  ISRline NonHandledINTCException          ;Vec 222,
  ISRline NonHandledINTCException          ;Vec 223,
  ISRline NonHandledINTCException          ;Vec 224,
  ISRline NonHandledINTCException          ;Vec 225,
  ISRline NonHandledINTCException          ;Vec 226,
  ISRline NonHandledINTCException          ;Vec 227,
  ISRline NonHandledINTCException          ;Vec 228,
  ISRline NonHandledINTCException          ;Vec 229,
  ISRline NonHandledINTCException          ;Vec 230,
  ISRline NonHandledINTCException          ;Vec 231,
  ISRline NonHandledINTCException          ;Vec 232,
  ISRline NonHandledINTCException          ;Vec 233,
  ISRline NonHandledINTCException          ;Vec 234,
  ISRline NonHandledINTCException          ;Vec 235,
  ISRline NonHandledINTCException          ;Vec 236,
  ISRline NonHandledINTCException          ;Vec 237,
  ISRline NonHandledINTCException          ;Vec 238,
  ISRline NonHandledINTCException          ;Vec 239,
  ISRline NonHandledINTCException          ;Vec 240,
  ISRline NonHandledINTCException          ;Vec 241,
  ISRline NonHandledINTCException          ;Vec 242,
  ISRline NonHandledINTCException          ;Vec 243,
  ISRline NonHandledINTCException          ;Vec 244,
  ISRline NonHandledINTCException          ;Vec 245,
  ISRline NonHandledINTCException          ;Vec 246,
  ISRline NonHandledINTCException          ;Vec 247,
  ISRline NonHandledINTCException          ;Vec 248,
  ISRline NonHandledINTCException          ;Vec 249,
  ISRline NonHandledINTCException          ;Vec 250,
  ISRline NonHandledINTCException          ;Vec 251,
  ISRline NonHandledINTCException          ;Vec 252,
  ISRline NonHandledINTCException          ;Vec 253,
  ISRline NonHandledINTCException          ;Vec 254,
  ISRline NonHandledINTCException          ;Vec 255,
  ISRline NonHandledINTCException          ;Vec 256,
  ISRline NonHandledINTCException          ;Vec 257,
  ISRline NonHandledINTCException          ;Vec 258,
  ISRline NonHandledINTCException          ;Vec 259,
  ISRline NonHandledINTCException          ;Vec 260,
  ISRline NonHandledINTCException          ;Vec 261,
  ISRline NonHandledINTCException          ;Vec 262,
  ISRline NonHandledINTCException          ;Vec 263,
  ISRline NonHandledINTCException          ;Vec 264,
  ISRline NonHandledINTCException          ;Vec 265,
  ISRline NonHandledINTCException          ;Vec 266,
  ISRline NonHandledINTCException          ;Vec 267,
  ISRline NonHandledINTCException          ;Vec 268,
  ISRline NonHandledINTCException          ;Vec 269,
  ISRline NonHandledINTCException          ;Vec 270,
  ISRline NonHandledINTCException          ;Vec 271,
  ISRline NonHandledINTCException          ;Vec 272,
  ISRline NonHandledINTCException          ;Vec 273,
  ISRline NonHandledINTCException          ;Vec 274,
  ISRline NonHandledINTCException          ;Vec 275,
  ISRline NonHandledINTCException          ;Vec 276,
  ISRline NonHandledINTCException          ;Vec 277,
  ISRline NonHandledINTCException          ;Vec 278,
  ISRline NonHandledINTCException          ;Vec 279,
  ISRline NonHandledINTCException          ;Vec 280,
  ISRline NonHandledINTCException          ;Vec 281,
  ISRline NonHandledINTCException          ;Vec 282,
  ISRline NonHandledINTCException          ;Vec 283,
  ISRline NonHandledINTCException          ;Vec 284,
  ISRline NonHandledINTCException          ;Vec 285,
  ISRline NonHandledINTCException          ;Vec 286,
  ISRline NonHandledINTCException          ;Vec 287,
  ISRline NonHandledINTCException          ;Vec 288,
  ISRline NonHandledINTCException          ;Vec 289,
  ISRline NonHandledINTCException          ;Vec 290,
  ISRline NonHandledINTCException          ;Vec 291,
  ISRline NonHandledINTCException          ;Vec 292,
  ISRline NonHandledINTCException          ;Vec 293,
  ISRline NonHandledINTCException          ;Vec 294,
  ISRline NonHandledINTCException          ;Vec 295,
  ISRline NonHandledINTCException          ;Vec 296,
  ISRline NonHandledINTCException          ;Vec 297,
  ISRline NonHandledINTCException          ;Vec 298,
  ISRline NonHandledINTCException          ;Vec 299,
  ISRline NonHandledINTCException          ;Vec 300,
  ISRline NonHandledINTCException          ;Vec 301,
  ISRline NonHandledINTCException          ;Vec 302,
  ISRline PIT2_ISR                         ;Vec 303,
  ISRline NonHandledINTCException          ;Vec 304,
  ISRline NonHandledINTCException          ;Vec 305,
  ISRline NonHandledINTCException          ;Vec 306,
  ISRline NonHandledINTCException          ;Vec 307,
  ISRline NonHandledINTCException          ;Vec 308,
  ISRline NonHandledINTCException          ;Vec 309,
  ISRline NonHandledINTCException          ;Vec 310,
  ISRline NonHandledINTCException          ;Vec 311,
  ISRline NonHandledINTCException          ;Vec 312,
  ISRline NonHandledINTCException          ;Vec 313,
  ISRline NonHandledINTCException          ;Vec 314,
  ISRline NonHandledINTCException          ;Vec 315,
  ISRline NonHandledINTCException          ;Vec 316,
  ISRline NonHandledINTCException          ;Vec 317,
  ISRline NonHandledINTCException          ;Vec 318,
  ISRline NonHandledINTCException          ;Vec 319,
  ISRline NonHandledINTCException          ;Vec 320,
  ISRline NonHandledINTCException          ;Vec 321,
  ISRline NonHandledINTCException          ;Vec 322,
  ISRline NonHandledINTCException          ;Vec 323,
  ISRline NonHandledINTCException          ;Vec 324,
  ISRline NonHandledINTCException          ;Vec 325,
  ISRline NonHandledINTCException          ;Vec 326,
  ISRline NonHandledINTCException          ;Vec 327,
  ISRline NonHandledINTCException          ;Vec 328,
  ISRline NonHandledINTCException          ;Vec 329,
  ISRline NonHandledINTCException          ;Vec 330,
  ISRline NonHandledINTCException          ;Vec 331,
  ISRline NonHandledINTCException          ;Vec 332,
  ISRline NonHandledINTCException          ;Vec 333,
  ISRline NonHandledINTCException          ;Vec 334,
  ISRline NonHandledINTCException          ;Vec 335,
  ISRline NonHandledINTCException          ;Vec 336,
  ISRline NonHandledINTCException          ;Vec 337,
  ISRline NonHandledINTCException          ;Vec 338,
  ISRline NonHandledINTCException          ;Vec 339,
  ISRline NonHandledINTCException          ;Vec 340,
  ISRline NonHandledINTCException          ;Vec 341,
  ISRline NonHandledINTCException          ;Vec 342,
  ISRline NonHandledINTCException          ;Vec 343,
  ISRline NonHandledINTCException          ;Vec 344,
  ISRline NonHandledINTCException          ;Vec 345,
  ISRline NonHandledINTCException          ;Vec 346,
  ISRline NonHandledINTCException          ;Vec 347,
  ISRline MCAN_ISR		           ;Vec 348,
  ISRline NonHandledINTCException          ;Vec 349,
  ISRline NonHandledINTCException          ;Vec 350,
  ISRline NonHandledINTCException          ;Vec 351,
  ISRline NonHandledINTCException          ;Vec 352,
  ISRline NonHandledINTCException          ;Vec 353,
  ISRline NonHandledINTCException          ;Vec 354,
  ISRline NonHandledINTCException          ;Vec 355,
  ISRline NonHandledINTCException          ;Vec 356,
  ISRline NonHandledINTCException          ;Vec 357,
  ISRline NonHandledINTCException          ;Vec 358,
  ISRline NonHandledINTCException          ;Vec 359,
  ISRline NonHandledINTCException          ;Vec 360,
  ISRline NonHandledINTCException          ;Vec 361,
  ISRline NonHandledINTCException          ;Vec 362,
  ISRline NonHandledINTCException          ;Vec 363,
  ISRline NonHandledINTCException          ;Vec 364,
  ISRline NonHandledINTCException          ;Vec 365,
  ISRline NonHandledINTCException          ;Vec 366,
  ISRline NonHandledINTCException          ;Vec 367,
  ISRline NonHandledINTCException          ;Vec 368,
  ISRline NonHandledINTCException          ;Vec 369,
  ISRline NonHandledINTCException          ;Vec 370,
  ISRline NonHandledINTCException          ;Vec 371,
  ISRline NonHandledINTCException          ;Vec 372,
  ISRline NonHandledINTCException          ;Vec 373,
  ISRline NonHandledINTCException          ;Vec 374,
  ISRline NonHandledINTCException          ;Vec 375,
  ISRline NonHandledINTCException          ;Vec 376,
  ISRline NonHandledINTCException          ;Vec 377,
  ISRline NonHandledINTCException          ;Vec 378,
  ISRline NonHandledINTCException          ;Vec 379,
  ISRline NonHandledINTCException          ;Vec 380,
  ISRline NonHandledINTCException          ;Vec 381,
  ISRline NonHandledINTCException          ;Vec 382,
  ISRline NonHandledINTCException          ;Vec 383,
  ISRline NonHandledINTCException          ;Vec 384,
  ISRline NonHandledINTCException          ;Vec 385,
  ISRline NonHandledINTCException          ;Vec 386,
  ISRline NonHandledINTCException          ;Vec 387,
  ISRline NonHandledINTCException          ;Vec 388,
  ISRline NonHandledINTCException          ;Vec 389,
  ISRline NonHandledINTCException          ;Vec 390,
  ISRline NonHandledINTCException          ;Vec 391,
  ISRline NonHandledINTCException          ;Vec 392,
  ISRline NonHandledINTCException          ;Vec 393,
  ISRline NonHandledINTCException          ;Vec 394,
  ISRline NonHandledINTCException          ;Vec 395,
  ISRline NonHandledINTCException          ;Vec 396,
  ISRline NonHandledINTCException          ;Vec 397,
  ISRline NonHandledINTCException          ;Vec 398,
  ISRline NonHandledINTCException          ;Vec 399,
  ISRline NonHandledINTCException          ;Vec 400,
  ISRline NonHandledINTCException          ;Vec 401,
  ISRline NonHandledINTCException          ;Vec 402,
  ISRline NonHandledINTCException          ;Vec 403,
  ISRline NonHandledINTCException          ;Vec 404,
  ISRline NonHandledINTCException          ;Vec 405,
  ISRline NonHandledINTCException          ;Vec 406,
  ISRline NonHandledINTCException          ;Vec 407,
  ISRline NonHandledINTCException          ;Vec 408,
  ISRline NonHandledINTCException          ;Vec 409,
  ISRline NonHandledINTCException          ;Vec 410,
  ISRline NonHandledINTCException          ;Vec 411,
  ISRline NonHandledINTCException          ;Vec 412,
  ISRline NonHandledINTCException          ;Vec 413,
  ISRline NonHandledINTCException          ;Vec 414,
  ISRline NonHandledINTCException          ;Vec 415,
  ISRline NonHandledINTCException          ;Vec 416,
  ISRline NonHandledINTCException          ;Vec 417,
  ISRline NonHandledINTCException          ;Vec 418,
  ISRline NonHandledINTCException          ;Vec 419,
  ISRline NonHandledINTCException          ;Vec 420,
  ISRline NonHandledINTCException          ;Vec 421,
  ISRline NonHandledINTCException          ;Vec 422,
  ISRline NonHandledINTCException          ;Vec 423,
  ISRline NonHandledINTCException          ;Vec 424,
  ISRline NonHandledINTCException          ;Vec 425,
  ISRline NonHandledINTCException          ;Vec 426,
  ISRline NonHandledINTCException          ;Vec 427,
  ISRline NonHandledINTCException          ;Vec 428,
  ISRline NonHandledINTCException          ;Vec 429,
  ISRline NonHandledINTCException          ;Vec 430,
  ISRline NonHandledINTCException          ;Vec 431,
  ISRline NonHandledINTCException          ;Vec 432,
  ISRline NonHandledINTCException          ;Vec 433,
  ISRline NonHandledINTCException          ;Vec 434,
  ISRline NonHandledINTCException          ;Vec 435,
  ISRline NonHandledINTCException          ;Vec 436,
  ISRline NonHandledINTCException          ;Vec 437,
  ISRline NonHandledINTCException          ;Vec 438,
  ISRline NonHandledINTCException          ;Vec 439,
  ISRline NonHandledINTCException          ;Vec 440,
  ISRline NonHandledINTCException          ;Vec 441,
  ISRline NonHandledINTCException          ;Vec 442,
  ISRline NonHandledINTCException          ;Vec 443,
  ISRline NonHandledINTCException          ;Vec 444,
  ISRline NonHandledINTCException          ;Vec 445,
  ISRline NonHandledINTCException          ;Vec 446,
  ISRline NonHandledINTCException          ;Vec 447,
  ISRline NonHandledINTCException          ;Vec 448,
  ISRline NonHandledINTCException          ;Vec 449,
  ISRline NonHandledINTCException          ;Vec 450,
  ISRline NonHandledINTCException          ;Vec 451,
  ISRline NonHandledINTCException          ;Vec 452,
  ISRline NonHandledINTCException          ;Vec 453,
  ISRline NonHandledINTCException          ;Vec 454,
  ISRline NonHandledINTCException          ;Vec 455,
  ISRline NonHandledINTCException          ;Vec 456,
  ISRline NonHandledINTCException          ;Vec 457,
  ISRline NonHandledINTCException          ;Vec 458,
  ISRline NonHandledINTCException          ;Vec 459,
  ISRline NonHandledINTCException          ;Vec 460,
  ISRline NonHandledINTCException          ;Vec 461,
  ISRline NonHandledINTCException          ;Vec 462,
  ISRline NonHandledINTCException          ;Vec 463,
  ISRline NonHandledINTCException          ;Vec 464,
  ISRline NonHandledINTCException          ;Vec 465,
  ISRline NonHandledINTCException          ;Vec 466,
  ISRline NonHandledINTCException          ;Vec 467,
  ISRline NonHandledINTCException          ;Vec 468,
  ISRline NonHandledINTCException          ;Vec 469,
  ISRline NonHandledINTCException          ;Vec 470,
  ISRline NonHandledINTCException          ;Vec 471,
  ISRline NonHandledINTCException          ;Vec 472,
  ISRline NonHandledINTCException          ;Vec 473,
  ISRline NonHandledINTCException          ;Vec 474,
  ISRline NonHandledINTCException          ;Vec 475,
  ISRline NonHandledINTCException          ;Vec 476,
  ISRline NonHandledINTCException          ;Vec 477,
  ISRline NonHandledINTCException          ;Vec 478,
  ISRline NonHandledINTCException          ;Vec 479,
  ISRline NonHandledINTCException          ;Vec 480,
  ISRline NonHandledINTCException          ;Vec 481,
  ISRline NonHandledINTCException          ;Vec 482,
  ISRline NonHandledINTCException          ;Vec 483,
  ISRline NonHandledINTCException          ;Vec 484,
  ISRline NonHandledINTCException          ;Vec 485,
  ISRline NonHandledINTCException          ;Vec 486,
  ISRline NonHandledINTCException          ;Vec 487,
  ISRline NonHandledINTCException          ;Vec 488,
  ISRline NonHandledINTCException          ;Vec 489,
  ISRline NonHandledINTCException          ;Vec 490,
  ISRline NonHandledINTCException          ;Vec 491,
  ISRline NonHandledINTCException          ;Vec 492,
  ISRline NonHandledINTCException          ;Vec 493,
  ISRline NonHandledINTCException          ;Vec 494,
  ISRline NonHandledINTCException          ;Vec 495,
  ISRline NonHandledINTCException          ;Vec 496,
  ISRline NonHandledINTCException          ;Vec 497,
  ISRline NonHandledINTCException          ;Vec 498,
  ISRline NonHandledINTCException          ;Vec 499,
  ISRline NonHandledINTCException          ;Vec 500,
  ISRline NonHandledINTCException          ;Vec 501,
  ISRline NonHandledINTCException          ;Vec 502,
  ISRline NonHandledINTCException          ;Vec 503,
  ISRline NonHandledINTCException          ;Vec 504,
  ISRline NonHandledINTCException          ;Vec 505,
  ISRline NonHandledINTCException          ;Vec 506,
  ISRline NonHandledINTCException          ;Vec 507,
  ISRline NonHandledINTCException          ;Vec 508,
  ISRline NonHandledINTCException          ;Vec 509,
  ISRline NonHandledINTCException          ;Vec 510,
  ISRline NonHandledINTCException          ;Vec 511,

#pragma endasm

// ****************************************************************************
// ***************************** Functions ************************************
// ****************************************************************************
       
//default code for unused ISR
void NonHandledINTCException(){
    while(1);
}//NonHandledINTCException
