#**************************************************************************/
#* FILE NAME: intc_sw_handlers.s            COPYRIGHT (c) Freescale 2015  */
#*                                                All Rights Reserved     */
#* DESCRIPTION:                                                           */
#*        This file creates prolog, epilog for C ISR and enables nested   */
#*        interrupts. This file starts in memory at the beginning of the  */
#*        ".xcptn" section designated by the label "IVOR4Handler".        */
#* WARNING:  This stack frame does not save the SPEs Accumulator, which   */
#*           is required if SPE instructions are used in ISRs.   If SPE   */
#*           instructions are used, the stack frame must include the      */
#*           accumulator, and prologue and epilogue must be modified.     */
#=========================================================================*/
    .globl   IVOR4_Handler

    .section  .vletext, vax
    .vle
  
    .equ  INTC_IACKR_PRC0, 0xfff48010 # Int. Acknowledge Register addr, Core0
    .equ  INTC_EOIR_PRC0,  0xfff48018 # End Of Interrupt Register addr, Core0
    .equ  INTC_IACKR_PRC1, 0xfff48014 # Int. Acknowledge Register addr, Core1
    .equ  INTC_EOIR_PRC1,  0xfff4801C # End Of Interrupt Register addr, Core1  

    .align 16

IVOR4_Handler:
prolog:
    e_stwu   r1, -0x50 (r1)  # Create stack frame and store back chain
    e_stw    r0, 0x24 (r1)   # Store GPR0 (working register)
    mfSRR1 r0                  
    e_stw    r0, 0x10 (r1)   # Store SRR1 (must be done before enabling EE)
    mfSRR0 r0                    
    e_stw    r0, 0x0C (r1)   # Store SRR0 (must be done before enabling EE)
    mfLR   r0              	
    e_stw    r0, 0x14 (r1)   # Store LR (will be used for ISR Vector)

    e_stw    r3, 0x28 (r1)   # Store GPR3 (working register)
    
    mfpir r3                 # Check core id
    se_cmpi r3,0
    se_bne iackr_core1       # if this is core 1, go to iackr_core1
iackr_core0:
    e_lis    r3, INTC_IACKR_PRC0@h     # Store address of IACKR in r3
    e_or2i   r3, INTC_IACKR_PRC0@l
    se_b iackr_end
iackr_core1:
    e_lis    r3, INTC_IACKR_PRC1@h     # Store address of IACKR in r3
    e_or2i   r3, INTC_IACKR_PRC1@l    
iackr_end:    
    
    e_lwz    r3, 0(r3)       # Store content of IACKR to r3 (vector table addr)
    e_lwz    r0, 0(r3)       # Read ISR address from ISR Vector Table address

    mtLR   r0                # Store ISR address to LR to use later

    mfmsr    r0              # As function prologs/epilogs may contain
    e_or2is  r0, 0x0200      # SPE instruction, enable SPE, as MSR
    mtmsr    r0              # register is cleared at this point


    wrteei 1                           # Set MSR[EE] = 1
    e_stw    r12, 0x4C (r1)            # Store GPR12
    e_stw    r11, 0x48 (r1)            # Store GPR11
    e_stw    r10, 0x44 (r1)            # Store GPR10
    e_stw    r9,  0x40 (r1)            # Store GPR9
    e_stw    r8,  0x3C (r1)            # Store GPR8
    e_stw    r7,  0x38 (r1)            # Store GPR7
    e_stw    r6,  0x34 (r1)            # Store GPR6
    e_stw    r5,  0x30 (r1)            # Store GPR5
    e_stw    r4,  0x2c (r1)            # Store GPR4  
	
    mfCR   r0                      
    e_stw    r0,  0x20 (r1)            # Store CR
    mfXER  r0                      
    e_stw    r0,  0x1C (r1)            # Store XER
    mfCTR  r0                      
    e_stw    r0,  0x18 (r1)            # Store CTR
								
    se_blrl                            # Branch to ISR, return here

epilog:
    mbar 0 # Ensure interrupt flag has finished clearing before INTC_EIOR write

	
    e_lwz    r0, 0x14 (r1)             
    mtLR   r0                          # Restore LR
    e_lwz    r0, 0x18 (r1)         
    mtCTR  r0                          # Restore CTR
    e_lwz    r0, 0x1C (r1)         
    mtXER  r0                          # Restore XER
    e_lwz    r0, 0x20 (r1)         
    mtcrf  0xff, r0                    # Restore CR
    e_lwz    r5,  0x30 (r1)            # Restore GPR5 
    e_lwz    r6,  0x34 (r1)            # Restore GPR6 
    e_lwz    r7,  0x38 (r1)            # Restore GPR7 
    e_lwz    r8,  0x3C (r1)            # Restore GPR8 
    e_lwz    r9,  0x40 (r1)            # Restore GPR9 
    e_lwz    r10, 0x44 (r1)            # Restore GPR10 
    e_lwz    r11, 0x48 (r1)            # Restore GPR11
    e_lwz    r12, 0x4C (r1)            # Restore GPR12 

    wrteei 0                 # Disable interrupts

    mfpir r4                 # Check core id
    se_cmpi r4,0
    se_bne eoir_core1        # if this is core 1, go to eoir_core1
eoir_core0:
    e_lis   r4, INTC_EOIR_PRC0@ha      # Load upper half of EIOR address to r4
    e_add16i  r4,r4, INTC_EOIR_PRC0@l  # Load lower half of EIOR address to R4
    se_b  eoir_end
eoir_core1:
    e_lis   r4, INTC_EOIR_PRC1@ha      # Load upper half of EIOR address to r4
    e_add16i  r4,r4, INTC_EOIR_PRC1@l  # Load lower half of EIOR address to R4
eoir_end:    

    se_li     r3,0
    e_stw   r3, 0(r4)                  # Write 0 to INTC_EOIR
    
    e_lwz    r3,  0x28 (r1)            # Restore GPR3
    e_lwz    r4,  0x2C (r1)            # Restore GPR4

    e_lwz    r0,  0x0C (r1)   	       
    mtSRR0 r0                          # Restore SRR0
    e_lwz    r0,  0x10 (r1)   	       
    mtSRR1 r0                          # Restore SRR1
    e_lwz    r0,  0x24 (r1)   	       # Restore GPR0 (working register)
    e_add16i  r1,r1, 0x50    		   # Clean up stack	

    se_rfi                             # Return from interrupt

